@@ -1,5 +1,3 @@
-// DeckGL typescript declarations are not great, so for now it's just js.
-
 import { BitmapLayer, BitmapLayerProps } from "@deck.gl/layers";
 
 import { decoder } from "../shader_modules";
@@ -12,33 +10,46 @@ import {
 
 import fsHillshading from "./hillshading2d.fs.glsl";
 
+// Most props are inherited from DeckGL's BitmapLayer. For a full list, see
+// https://deck.gl/docs/api-reference/layers/bitmap-layer
+//
+// The property map is encoded in an image and sent in the `image` prop of the BitmapLayer.
+// For more details on the property map encoding, see colormapLayer.ts
+export interface Hillshading2DProps<D> extends BitmapLayerProps<D> {
+    // Min and max property values.
+    valueRange: [number, number];
+
+    // Direction the light comes from.
+    lightDirection: [number, number, number];
+    // Intensity of light that is applied to the whole map uniformly.
+    ambientLightIntensity: number;
+    // Intensity of light that is applied to the lightened potions of the map.
+    diffuseLightIntensity: number;
+
+    // By default, scale the [0, 256*256*256-1] decoded values to [0, 1]
+    valueDecoder: ValueDecoder;
+}
+
 const defaultProps = {
+    name: "Hill shading",
     valueRange: { type: "array" },
     lightDirection: { type: "array", value: [1, 1, 1] },
     ambientLightIntensity: { type: "number", value: 0.5 },
     diffuseLightIntensity: { type: "number", value: 0.5 },
-    opacity: { type: "number", min: 0, max: 1, value: 1 },
     valueDecoder: {
         type: "object",
         value: {
             rgbScaler: [1, 1, 1],
-            // Scale [0, 256*256*256-1] to [0, 1]
+            // By default, scale the [0, 256*256*256-1] decoded values to [0, 1]
             floatScaler: 1.0 / (256.0 * 256.0 * 256.0 - 1.0),
             offset: 0,
             step: 0,
         },
     },
+    opacity: 1,
+    pickable: true,
 };
 
-export interface Hillshading2DProps<D> extends BitmapLayerProps<D> {
-    valueRange: [number, number];
-    lightDirection: [number, number, number];
-    ambientLightIntensity: number;
-    diffuseLightIntensity: number;
-    opacity: number;
-    valueDecoder: ValueDecoder;
-}
-
 export default class Hillshading2DLayer extends BitmapLayer<
     unknown,
     Hillshading2DProps<unknown>
@@ -62,6 +73,7 @@ export default class Hillshading2DLayer extends BitmapLayer<
             super.draw({
                 uniforms: {
                     ...uniforms,
+                    // Send extra uniforms to the shader.
                     bitmapResolution: [
                         this.props.image.width,
                         this.props.image.height,
@@ -70,7 +82,6 @@ export default class Hillshading2DLayer extends BitmapLayer<
                     lightDirection: this.props.lightDirection,
                     ambientLightIntensity: this.props.ambientLightIntensity,
                     diffuseLightIntensity: this.props.diffuseLightIntensity,
-                    opacity: this.props.opacity,
                 },
                 moduleParameters: mergedModuleParams,
             });
@@ -81,7 +92,9 @@ export default class Hillshading2DLayer extends BitmapLayer<
     // eslint-disable-next-line
     getShaders(): any {
         const parentShaders = super.getShaders();
+        // Overwrite the BitmapLayer's default fragment shader with ours, that does hillshading.
         parentShaders.fs = fsHillshading;
+        // Add the decoder shader module to our colormap shader, so we can use the decoder function from our shader.
         parentShaders.modules.push(decoder);
         return parentShaders;
     }
@@ -95,11 +108,15 @@ export default class Hillshading2DLayer extends BitmapLayer<
             ...defaultProps.valueDecoder.value,
             ...this.props.valueDecoder,
         };
+        // The picked color is the one in raw image, not the one after hillshading.
+        // We just need to decode that RGB color into a property float value.
         const val = decodeRGB(info.color, mergedDecoder, this.props.valueRange);
 
         return {
             ...info,
-            index: 0, // Picking color doesn't represent object index in this layer
+            // Picking color doesn't represent object index in this layer.
+            // For more details, see https://deck.gl/docs/developer-guide/custom-layers/picking
+            index: 0,
             propertyValue: val,
         };
     }
