@@ -6,20 +6,23 @@
 
 import json
 import dash
-from dash.dependencies import Input, Output
-import webviz_subsurface_components
 import dash_html_components as html
 
+import webviz_subsurface_components
+
+
 # Basic test for the component rendering.
 def test_render_hm(dash_duo):
 
-    with open("tests/data/hm_data.json", "r") as json_file:
+    with open("tests/data/hm_data.json", encoding="utf8") as json_file:
         hm_data = json.load(json_file)
 
     app = dash.Dash(__name__)
 
     app.layout = html.Div(
-        [webviz_subsurface_components.HistoryMatch(id="parameters", data=hm_data),]
+        [
+            webviz_subsurface_components.HistoryMatch(id="parameters", data=hm_data),
+        ]
     )
 
     dash_duo.start_server(app)
